import { IAxiosAjaxUtils } from "@snickerdoodlelabs/common-utils";
import { ICryptoUtils } from "@snickerdoodlelabs/node-utils";
import { AjaxError, BigNumberString, EarnedReward, EVMAccountAddress, EVMContractAddress, EVMPrivateKey, HexString, IDynamicRewardParameter, IpfsCID, Signature, TokenId, URLString, IQueryDeliveryItems, PossibleReward } from "@snickerdoodlelabs/objects";
import { ResultAsync } from "neverthrow";
import { IInsightPlatformRepository } from "./IInsightPlatformRepository.js";
export declare class InsightPlatformRepository implements IInsightPlatformRepository {
    protected cryptoUtils: ICryptoUtils;
    protected ajaxUtils: IAxiosAjaxUtils;
    constructor(cryptoUtils: ICryptoUtils, ajaxUtils: IAxiosAjaxUtils);
    clearAllBackups(dataWalletKey: EVMPrivateKey, insightPlatformBaseUrl: URLString, walletAddress: EVMAccountAddress): ResultAsync<void, AjaxError>;
    getSignedUrl(dataWalletKey: EVMPrivateKey, insightPlatformBaseUrl: URLString, fileName: string): ResultAsync<URLString, AjaxError>;
    receivePreviews(consentContractAddress: EVMContractAddress, tokenId: TokenId, queryCID: IpfsCID, signingKey: EVMPrivateKey, insightPlatformBaseUrl: URLString, queryDeliveryItems: IQueryDeliveryItems): ResultAsync<PossibleReward[], AjaxError>;
    deliverInsights(consentContractAddress: EVMContractAddress, tokenId: TokenId, queryCID: IpfsCID, insights: IQueryDeliveryItems, rewardParameters: IDynamicRewardParameter[], signingKey: EVMPrivateKey, insightPlatformBaseUrl: URLString): ResultAsync<EarnedReward[], AjaxError>;
    executeMetatransaction(accountAddress: EVMAccountAddress, contractAddress: EVMContractAddress, nonce: BigNumberString, value: BigNumberString, gas: BigNumberString, data: HexString, metatransactionSignature: Signature, signingKey: EVMPrivateKey, insightPlatformBaseUrl: URLString): ResultAsync<void, AjaxError>;
}
//# sourceMappingURL=InsightPlatformRepository.d.ts.map