var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
import { IAxiosAjaxUtilsType, } from "@snickerdoodlelabs/common-utils";
import { ICryptoUtilsType } from "@snickerdoodlelabs/node-utils";
import { clearCloudBackupsTypes, executeMetatransactionTypes, insightDeliveryTypes, insightPreviewTypes, signedUrlTypes, snickerdoodleSigningDomain, } from "@snickerdoodlelabs/signature-verification";
import { inject, injectable } from "inversify";
import { urlJoin } from "url-join-ts";
let InsightPlatformRepository = class InsightPlatformRepository {
    constructor(cryptoUtils, ajaxUtils) {
        this.cryptoUtils = cryptoUtils;
        this.ajaxUtils = ajaxUtils;
    }
    clearAllBackups(dataWalletKey, insightPlatformBaseUrl, walletAddress) {
        const signableData = {
            walletAddress: walletAddress,
        };
        return this.cryptoUtils
            .signTypedData(snickerdoodleSigningDomain, clearCloudBackupsTypes, signableData, dataWalletKey)
            .andThen((signature) => {
            const url = new URL(urlJoin(insightPlatformBaseUrl, "/clearAllBackups"));
            const postBody = {
                walletAddress: walletAddress,
                signature: signature,
            };
            return this.ajaxUtils.post(url, postBody);
        });
    }
    getSignedUrl(dataWalletKey, insightPlatformBaseUrl, fileName) {
        const signableData = {
            fileName: fileName,
        };
        return this.cryptoUtils
            .signTypedData(snickerdoodleSigningDomain, signedUrlTypes, signableData, dataWalletKey)
            .andThen((signature) => {
            const url = new URL(urlJoin(insightPlatformBaseUrl, "/getSignedUrl"));
            const postBody = {
                fileName: fileName,
                signature: signature,
            };
            return this.ajaxUtils.post(url, postBody);
        });
    }
    //
    receivePreviews(consentContractAddress, tokenId, queryCID, signingKey, insightPlatformBaseUrl, queryDeliveryItems) {
        const signableData = {
            consentContractId: consentContractAddress,
            tokenId: tokenId,
            queryCID: queryCID,
            queryDeliveryItems: JSON.stringify(queryDeliveryItems),
        };
        return this.cryptoUtils
            .signTypedData(snickerdoodleSigningDomain, insightPreviewTypes, signableData, signingKey)
            .andThen((signature) => {
            const url = new URL(urlJoin(insightPlatformBaseUrl, "/insights/responses/preview"));
            /* Following schema from .yaml file: */
            /* https://github.com/SnickerdoodleLabs/protocol/blob/develop/documentation/openapi/Insight%20Platform%20API.yaml */
            return this.ajaxUtils.post(url, {
                consentContractId: consentContractAddress,
                queryCID: queryCID,
                tokenId: tokenId.toString(),
                queryDeliveryItems: queryDeliveryItems,
                signature: signature,
            });
        });
    }
    deliverInsights(consentContractAddress, tokenId, queryCID, insights, rewardParameters, signingKey, insightPlatformBaseUrl) {
        let parameters = JSON.stringify([]);
        if (rewardParameters !== undefined) {
            parameters = JSON.stringify(rewardParameters);
        }
        const signableData = {
            consentContractId: consentContractAddress,
            tokenId: tokenId,
            queryCID: queryCID,
            insights: JSON.stringify(insights),
            rewardParameters: JSON.stringify(rewardParameters),
        };
        return this.cryptoUtils
            .signTypedData(snickerdoodleSigningDomain, insightDeliveryTypes, signableData, signingKey)
            .andThen((signature) => {
            const url = new URL(urlJoin(insightPlatformBaseUrl, "insights/responses"));
            return this.ajaxUtils.post(url, {
                consentContractId: consentContractAddress,
                tokenId: tokenId.toString(),
                queryCID: queryCID,
                insights: insights,
                rewardParameters: rewardParameters,
                signature: signature,
            });
        });
    }
    executeMetatransaction(accountAddress, contractAddress, nonce, value, gas, data, metatransactionSignature, signingKey, insightPlatformBaseUrl) {
        const signingData = {
            accountAddress: accountAddress,
            contractAddress: contractAddress,
            nonce: nonce,
            value: value,
            gas: gas,
            data: data,
            metatransactionSignature: metatransactionSignature,
        };
        return this.cryptoUtils
            .signTypedData(snickerdoodleSigningDomain, executeMetatransactionTypes, signingData, signingKey)
            .andThen((signature) => {
            const url = new URL(urlJoin(insightPlatformBaseUrl, "metatransaction"));
            const postBody = {
                accountAddress: accountAddress,
                contractAddress: contractAddress,
                nonce: nonce,
                value: value,
                gas: gas,
                data: data,
                metatransactionSignature: metatransactionSignature,
                requestSignature: signature,
            };
            return this.ajaxUtils.post(url, postBody);
        })
            .map(() => { });
    }
};
InsightPlatformRepository = __decorate([
    injectable(),
    __param(0, inject(ICryptoUtilsType)),
    __param(1, inject(IAxiosAjaxUtilsType)),
    __metadata("design:paramtypes", [Object, Object])
], InsightPlatformRepository);
export { InsightPlatformRepository };
//# sourceMappingURL=InsightPlatformRepository.js.map